@@ -27,6 +27,19 @@ SVG_XMLNS = 'xmlns="http://www.w3.org/2000/svg" ' + 'xmlns:xlink="http://www.w3.
 B64IMG_TMPL = '<img src="data:image/svg+xml;base64,{img_text}"/>'
 
 
+FENCE_RE       = re.compile(r"^(`{3,}|~{3,})")
+BLOCK_START_RE = re.compile(r"^(`{3,}|~{3,})math")
+BLOCK_CLEAN_RE = re.compile(r"^(`{3,}|~{3,})math(.*)(\1)$", flags=re.DOTALL)
+
+
+def _clean_block_text(block_text: str) -> str:
+    block_match = BLOCK_CLEAN_RE.match(block_text)
+    if block_match:
+        return block_match.group(2)
+    else:
+        return block_text
+
+
 def make_marker_id(text: str) -> str:
     data = text.encode("utf-8")
     return hashlib.md5(data).hexdigest()
@@ -56,19 +69,6 @@ def svg2img(html: str) -> str:
     return html
 
 
-def _clean_block_text(block_text: str) -> str:
-    if block_text.startswith("```math"):
-        block_text = block_text[len("```math") :]
-    elif block_text.startswith("~~~math"):
-        block_text = block_text[len("~~~math") :]
-
-    if block_text.endswith("```"):
-        block_text = block_text[: -len("```")]
-    elif block_text.endswith("~~~"):
-        block_text = block_text[: -len("~~~")]
-    return block_text
-
-
 def tex2html(tex: str, options: wrapper.Options = None) -> str:
     if options:
         no_inline_svg = options.get("no_inline_svg", False)
@@ -190,10 +190,6 @@ class KatexExtension(Extension):
         md.registerExtension(self)
 
 
-FENCE_RE      = re.compile(r"^(```|~~~)")
-MATH_FENCE_RE = re.compile(r"^(```|~~~)math")
-
-
 class KatexPreprocessor(Preprocessor):
     def __init__(self, md, ext: KatexExtension) -> None:
         super().__init__(md)
@@ -202,7 +198,7 @@ class KatexPreprocessor(Preprocessor):
     def _make_tag_for_block(self, block_lines: typ.List[str]) -> str:
         block_text = "\n".join(block_lines).rstrip()
         marker_id  = make_marker_id("block" + block_text)
-        marker_tag = f"<p id='katex{marker_id}'>katex{marker_id}</p>"
+        marker_tag = f"<p id=\"tmp_md_katex{marker_id}\">katex{marker_id}</p>"
 
         math_html = md_block2html(block_text, self.ext.options)
         tag_text  = f"<p>{math_html}</p>"
@@ -211,7 +207,7 @@ class KatexPreprocessor(Preprocessor):
 
     def _make_tag_for_inline(self, inline_text: str) -> str:
         marker_id  = make_marker_id("inline" + inline_text)
-        marker_tag = f"<span id='katex{marker_id}'>katex{marker_id}</span>"
+        marker_tag = f"<span id=\"tmp_md_katex{marker_id}\">katex{marker_id}</span>"
 
         math_html = md_inline2html(inline_text, self.ext.options)
         self.ext.math_html[marker_tag] = math_html
@@ -241,7 +237,7 @@ class KatexPreprocessor(Preprocessor):
                 del block_lines[:]
                 yield marker_tag
             else:
-                math_fence_match = MATH_FENCE_RE.match(line)
+                math_fence_match = BLOCK_START_RE.match(line)
                 fence_match      = FENCE_RE.match(line)
                 if math_fence_match:
                     is_in_math_fence     = True
@@ -293,11 +289,13 @@ class KatexPostprocessor(Postprocessor):
             text = KATEX_STYLES + text
 
         for marker_tag, html in self.ext.math_html.items():
-            wrapped_marker = "<p>" + marker_tag + "</p>"
-            if wrapped_marker in text:
-                text = text.replace(wrapped_marker, html)
-            elif marker_tag in text:
-                text = text.replace(marker_tag, html)
+            if marker_tag in text:
+                wrapped_marker = "<p>" + marker_tag + "</p>"
+                while marker_tag in text:
+                    if wrapped_marker in text:
+                        text = text.replace(wrapped_marker, html)
+                    else:
+                        text = text.replace(marker_tag, html)
             else:
                 logger.warning(f"KatexPostprocessor couldn't find: {marker_tag}")
 
